@@ -5,14 +5,14 @@ descriptivesClass <- R6::R6Class(
     private=list(
         #### Member variables ----
         colArgs = list(
-            name = c("n", "missing", "mean", "median", "mode", "sum", "sd", "variance", "range",
-                     "min", "max", "se", "skew", "kurt", "quart1", "quart2", "quart3"),
-            title = c("N", "Missing", "Mean", "Median", "Mode", "Sum", "Standard deviation", "Variance",
-                      "Range", "Minimum", "Maximum", "Standard error", "Skewness", "Kurtosis",
-                      "25th percentile", "50th percentile", "75th percentile"),
-            type = c(rep("integer", 2), rep("number", 15)),
-            visible = c("(n)", "(missing)", "(mean)", "(median)", "(mode)", "(sum)", "(sd)", "(variance)", "(range)",
-                        "(min)", "(max)", "(se)", "(skew)", "(kurt)", "(quart)", "(quart)", "(quart)")
+            name = c("n", "missing", "mean", "se", "median", "mode", "sum", "sd", "variance", "range",
+                     "min", "max", "skew", "seSkew", "kurt", "seKurt", "quart1", "quart2", "quart3"),
+            title = c("N", "Missing", "Mean", "Std. error mean", "Median", "Mode", "Sum", "Standard deviation", "Variance",
+                      "Range", "Minimum", "Maximum", "Skewness", "Std. error skewness",
+                      "Kurtosis", "Std. error kurtosis", "25th percentile", "50th percentile", "75th percentile"),
+            type = c(rep("integer", 2), rep("number", 17)),
+            visible = c("(n)", "(missing)", "(mean)", "(se)", "(median)", "(mode)", "(sum)", "(sd)", "(variance)", "(range)",
+                        "(min)", "(max)", "(skew)", "(skew)", "(kurt)", "(kurt)", "(quart)", "(quart)", "(quart)")
         ),
         levels = NULL,
 
@@ -193,7 +193,8 @@ descriptivesClass <- R6::R6Class(
 
                         table$addColumn(name='levels', title='Levels', type='text')
                         table$addColumn(name='counts', title='Counts', type='integer')
-                        # table$addColumn(name='perc', title='% of Total', type='number')
+                        table$addColumn(name='pc', title='% of Total', type='number', format='pc')
+                        table$addColumn(name='cumpc', title='Cumulative %', type='number', format='pc')
 
                         for (k in seq_along(levels))
                             table$addRow(levels[k], values = list(levels = levels[k]))
@@ -436,10 +437,19 @@ descriptivesClass <- R6::R6Class(
                     freq <- freqs[[var]]
 
                     if (length(splitBy) == 0) {
-
+                        n <- sum(freq)
+                        cumsum <- 0
                         for (k in seq_along(levels)) {
                             counts <- as.numeric(freq[levels[k]])
-                            table$setRow(rowNo=k, values=list(counts=counts))
+                            cumsum <- cumsum + counts
+                            pc <- counts / n
+                            cumpc <- cumsum / n
+                            if (is.na(pc)) pc <- 0
+                            if (is.na(cumpc)) cumpc <- 0
+                            table$setRow(rowNo=k, values=list(
+                                counts=counts,
+                                pc=pc,
+                                cumpc=cumpc))
                         }
 
                     } else {
@@ -835,8 +845,12 @@ descriptivesClass <- R6::R6Class(
                 stats[['se']] <- sqrt(var(column)/length(column))
 
                 deviation <- column-mean(column)
-                stats[['skew']] <- sum(deviation^3)/(length(column)*sd(column)^3)
-                stats[['kurt']] <- sum(deviation^4)/(length(column)*var(column)^2)
+                skew <- private$.skewness(column)
+                kurt <- private$.kurtosis(column)
+                stats[['skew']] <- skew$skew
+                stats[['seSkew']] <- skew$seSkew
+                stats[['kurt']] <- kurt$kurt
+                stats[['seKurt']] <- kurt$seKurt
 
                 stats[['quart1']] <- as.numeric(quantile(column, c(.25)))
                 stats[['quart2']] <- as.numeric(quantile(column, c(.5)))
@@ -855,8 +869,8 @@ descriptivesClass <- R6::R6Class(
             } else if (jmvcore::canBeNumeric(column)) {
 
                 l <- list(mean=NaN, median=NaN, mode=NaN, sum=NaN, sd=NaN, variance=NaN,
-                          range=NaN, min=NaN, max=NaN, se=NaN, skew=NaN, kurt=NaN,
-                          quart1=NaN, quart2=NaN, quart3=NaN)
+                          range=NaN, min=NaN, max=NaN, se=NaN, skew=NaN, seSkew=NaN,
+                          kurt=NaN, seKurt=NaN, quart1=NaN, quart2=NaN, quart3=NaN)
 
                 pcNEqGr <- self$options$pcNEqGr
                 if ( ! (self$options$quart && pcNEqGr == 4)) {
@@ -869,8 +883,8 @@ descriptivesClass <- R6::R6Class(
             } else {
 
                 l <- list(mean='', median='', mode='', sum='', sd='', variance='',
-                          range='', min='', max='', se='', skew='', kurt='',
-                          quart1='', quart2='', quart3='')
+                          range='', min='', max='', se='', skew='', seSkew='',
+                          kurt='', seKurt='', quart1='', quart2='', quart3='')
 
                 pcNEqGr <- self$options$pcNEqGr
                 if ( ! (self$options$quart && pcNEqGr == 4)) {
@@ -928,6 +942,40 @@ descriptivesClass <- R6::R6Class(
             }
 
             return(c(width, height))
+        },
+        .kurtosis = function(x) {
+
+            # https://stats.idre.ucla.edu/other/mult-pkg/faq/general/faq-whats-with-the-different-formulas-for-kurtosis/
+
+            n <- length(x)
+            s2 <- sum((x - mean(x))^2)
+            s4 <- sum((x - mean(x))^4)
+            v <- s2 / (n-1)
+
+            e1 <- (n * (n + 1)) / ((n - 1) * (n - 2) * (n - 3))
+            e2 <- s4 / (v^2)
+            e3 <- (-3 * (n - 1)^2) / ((n - 2) * (n - 3))
+            kurtosis <- e1 * e2 + e3
+
+            varSkew <- 6 * n * (n - 1) / ((n - 2) * (n + 1) * (n + 3))
+            varKurt <- 4 * (n^2 - 1) * varSkew / ((n - 3) * (n + 5))
+            seKurt <- sqrt(varKurt)
+
+            return(list(kurt=kurtosis, seKurt=seKurt))
+        },
+        .skewness = function(x) {
+
+            n <- length(x)
+            x <- x - mean(x)
+
+            e1 <- sqrt(n * (n - 1))/(n - 2)
+            e2 <- sqrt(n) * sum(x^3)/(sum(x^2)^(3/2))
+            skewness <- e1 * e2
+
+            varSkew <- 6 * n * (n - 1) / ((n - 2) * (n + 1) * (n + 3))
+            seSkew <- sqrt(varSkew)
+
+            return(list(skew=skewness, seSkew=seSkew))
         }
     )
 )
